fuzzy_match_positions_graphemes_latest

Function fuzzy_match_positions_graphemes_latest 

pub fn fuzzy_match_positions_graphemes_latest(
    query: &str,
    candidate: &str,
) -> Option<(Vec<usize>, i64)>
Latest version of the scored fuzzy matcher.

This function may change its scoring model in a future release. If you need a pinned scoring model, call a versioned function such as fuzzy_match_positions_graphemes_v1.