fuzzy_match_positions_graphemes_v1

Function fuzzy_match_positions_graphemes_v1 

pub fn fuzzy_match_positions_graphemes_v1(
    query: &str,
    candidate: &str,
) -> Option<(Vec<usize>, i64)>
Version 1 of the scored fuzzy matcher.

This function’s scoring model is intended to be stable across patch/minor releases. If a future scoring model is introduced, it will be exposed as a new versioned function (for example, ..._v2).