pub fn ellipsis_to_cells_spans(
registry: &GlyphRegistry,
spans: &[Span],
w: usize,
ellipsis_span: &Span,
) -> Vec<Span>Expand description
Ellipsize spans to at most w cells using the provided ellipsis_span.
If the ellipsis span does not fit, it will be clipped to w.