pub fn measure_cells_spans(registry: &GlyphRegistry, spans: &[Span]) -> usizeExpand description
Measure spans in terminal cells using the provided glyph registry.
pub fn measure_cells_spans(registry: &GlyphRegistry, spans: &[Span]) -> usizeMeasure spans in terminal cells using the provided glyph registry.