pub fn ellipsis_to_cells_text(
registry: &GlyphRegistry,
text: &str,
w: usize,
ellipsis: &str,
) -> StringExpand description
Ellipsize a plain string to at most w cells using the provided ellipsis.
If the ellipsis itself does not fit, it will be clipped to w.